PyGame AI
=========

PyGame AI is a package built on PyGame that aims at implementing a bunch of common algorithms and techniques often used in Videogame AI. It is still a work in progress.

You can install it with pip:

    pip install pygame-ai
    
And import it by doing:

    import pygame_ai
    
or

    import pygame_ai as pai
    
Please [Read The Docs](https://pygame-ai.readthedocs.io/) to learn all about the library. You can download an [Example Game](https://pygame-ai.readthedocs.io/en/latest/example_game.html) to see what the library can do and follow the [Pygame AI Guide](https://pygame-ai.readthedocs.io/en/latest/guide.html) to learn how to use it.
